@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader;
 # ABSTRACT: Classe de base pour le chargement de notices biblio/autorité
-$Koha::Contrib::Sudoc::Loader::VERSION = '2.20';
+$Koha::Contrib::Sudoc::Loader::VERSION = '2.21';
 use Moose;
 use Modern::Perl;
 use utf8;
@@ -9,7 +9,7 @@ use Koha::Contrib::Sudoc::Converter;
 use Log::Dispatch;
 use Log::Dispatch::Screen;
 use Log::Dispatch::File;
-use Try::Tiny;
+use Class::Load ':all';
 use DateTime;
 
 
@@ -76,15 +76,18 @@ sub BUILD {
     ) );
 
     # Instanciation du converter
-    my $class = $self->sudoc->c->{biblio}->{converter};
-    try {
-        Class::MOP::load_class($class);
-    } catch {
-        $self->log->warning(
-            "Attention : le convertisseur $class est introuvable dans le répertoire 'lib'. " .
-            "Le convertisseur par défaut sera utilisé.\n") if $class;
-        $class = 'Koha::Contrib::Sudoc::Converter';
-    };
+    my $class = 'Koha::Contrib::Sudoc::Converter';
+    if ( my $local_class = $self->sudoc->c->{biblio}->{converter} ) {
+        if ( try_load_class($local_class) ) {
+            $class = $local_class;
+        }
+        else {
+            $self->log->warning(
+                "Attention : le convertisseur $local_class est introuvable dans le répertoire 'lib'. " .
+                "Le convertisseur par défaut sera utilisé.\n");
+        }
+    }
+    load_class($class);
     $class = $class->new(sudoc => $self->sudoc, log => $self->log);
     $self->converter($class);
 }
@@ -140,7 +143,7 @@ Koha::Contrib::Sudoc::Loader - Classe de base pour le chargement de notices bibl
 
 =head1 VERSION
 
-version 2.20
+version 2.21
 
 =head1 AUTHOR
 
